@@ -3,7 +3,7 @@ class DiscreteOperatorCounter:
     def __init__(self, n: int):
         self.n = n
 
-    def count_operators(self) -> int:
+    def count_operators(self, **kwargs) -> int:
         """
         Counts the number of discrete operators defined over the finite chain Ln.
 
